from owslib.swe.sensor.sml import SensorML

class IoosDescribeSensor(SensorML):
    def get_true(self):
        return True